import 'package:flutter/material.dart';
import 'package:fl_chart/fl_chart.dart';

import '../../../config/app_colors.dart';
import '../../../models/timeline.dart';
import '../../../ui/widgets/charts/custom_bar_chart.dart';

class ChartTimelineCounts extends CustomBarChart {
  final TimelineData chartData;

  ChartTimelineCounts({super.key, required this.chartData});

  final double chartHeight = 120.0;
  final double verticalTicksInterval = 50;

  @override
  Widget build(BuildContext context) {
    return Container(
      height: this.chartHeight,
      child: LayoutBuilder(builder: (context, constraints) {
        return getBarChart(
          barWidth: this.getBarWidth(constraints.maxWidth, this.chartData.data.keys.length),
          backgroundColor: Theme.of(context).colorScheme.onSurface,
        );
      }),
    );
  }

  double getMaxCountsValue() {
    double maxValue = 0;

    this.chartData.data.keys.forEach((key) {
      TimelineDataValue? value = this.chartData.data[key];
      if (value != null) {
        double counts = value.counts.toDouble();
        if (counts > maxValue) {
          maxValue = counts;
        }
      }
    });

    return maxValue;
  }

  List<BarChartGroupData> getDataCounts(double barWidth) {
    List<BarChartGroupData> data = [];

    final barColor = AppColors.contentColorOrange;

    this.chartData.data.keys.forEach((key) {
      TimelineDataValue? value = this.chartData.data[key];
      if (value != null) {
        final int date = DateTime.parse(key).millisecondsSinceEpoch;
        final double counts = value.counts.toDouble();

        data.add(this.getBarItem(
          x: date,
          values: [counts],
          barColors: [barColor],
          barWidth: barWidth,
        ));
      }
    });

    return data;
  }
}
